==> apache-nuttx-apps-12.1.0.tar.gz: apps/system/uorb/sensor/gesture.h <==
/****************************************************************************
 * apps/system/uorb/sensor/gesture.h
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

#ifndef __APPS_SYSTEM_UORB_SENSOR_GESTURE_H
#define __APPS_SYSTEM_UORB_SENSOR_GESTURE_H

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <uORB/uORB.h>

/****************************************************************************
 * Public Data
 ****************************************************************************/

/* register this as object request broker structure */

ORB_DECLARE(sensor_wake_gesture);
ORB_DECLARE(sensor_wake_gesture_uncal);

#endif

==> apache-nuttx-apps-12.7.0.tar.gz: apps/system/uorb/sensor/gesture.h <==
/****************************************************************************
 * apps/system/uorb/sensor/gesture.h
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

#ifndef __APPS_SYSTEM_UORB_SENSOR_GESTURE_H
#define __APPS_SYSTEM_UORB_SENSOR_GESTURE_H

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <uORB/uORB.h>

/****************************************************************************
 * Public Data
 ****************************************************************************/

/* register this as object request broker structure */

ORB_DECLARE(sensor_glance_gesture);
ORB_DECLARE(sensor_glance_gesture_uncal);
ORB_DECLARE(sensor_offbody_detector);
ORB_DECLARE(sensor_offbody_detector_uncal);
ORB_DECLARE(sensor_pickup_gesture);
ORB_DECLARE(sensor_pickup_gesture_uncal);
ORB_DECLARE(sensor_wrist_tilt);
ORB_DECLARE(sensor_wrist_tilt_uncal);
ORB_DECLARE(sensor_wake_gesture);
ORB_DECLARE(sensor_wake_gesture_uncal);

#endif
